function [WorstRank,RunTime]=WorstRankFun(mInput,mOutput,iDMUo)
%inputs
%mInput: matrix of inputs, x_jm, row: DMU, column: input
%mOutput:matrix of outputs, x_jn, row: DMU, column: output
%jDMUo: a number, the DMU to be evaluated

%output
%WorstRank: number, the Worst rank for DMUo
%RunTime: time in seconds, running time for computing DMUo's Worst ranking

problem_statement_WorstRank_CARGRB=...
             ['minimize', char(10),...
              'mip=1', char(10),...
              '  pr_pen_g(0, matrix_H)', char(10),...
              'Constraint: = 1', char(10),...
              '  linearmulti(matrix_Aeq)',char(10),...
              'Box: >= 0',char(10),...
              'Solver: CARGRB,init_point=0.0001,timelimit=100']; 

problem_statement_WorstRank_VAN=...
             ['minimize', char(10),...
              'mip=1', char(10),...
              '  pr_pen_g(0, matrix_H)', char(10),...
              'Constraint: = 1', char(10),...
              '  linearmulti(matrix_Aeq)',char(10),...
              'Box: >= 0',char(10),...
              'Solver: VAN,init_point=0.0001,timelimit=100'];           
          
[J,nInput]=size(mInput);
[J1,nOutput]=size(mOutput);
vInputDMUo=mInput(iDMUo,:);
vOutputDMUo=mOutput(iDMUo,:);

colnames={};
for i=1:nInput; colnames{i}=sprintf('nu_%g',i); end
for i=1:nOutput; colnames{nInput+i}=sprintf('mu_%g',i); end
mDMU=[mInput,-mOutput];

%H=mDMU-[vInputDMUo,-vOutputDMUo].*ones(J,1);
for i=1:J; H(i,:)=mDMU(i,:)-[vInputDMUo,-vOutputDMUo]; end

iargstruc_Rank(1) = matrix_pack('matrix_H',H,colnames);
Aeq=[vInputDMUo,vOutputDMUo];
iargstruc_Rank(2) = matrix_pack('matrix_Aeq',Aeq,colnames);

[solution, outargstruc] = mpsg_solver(problem_statement_WorstRank_CARGRB, iargstruc_Rank);
fval= tbpsg_solution(solution, outargstruc,'objective');  
status=tbpsg_solution(solution, outargstruc,'solution_status');
vTime=tbpsg_solution(solution, outargstruc,'time');
RunTime=vTime(3);
WorstRank=J-J*fval; 

vSoluBestBRank=get_optimalpoint(solution, iargstruc_Rank, outargstruc);
for iInput=1:nInput
    vOptNu(iInput,1)=vSoluBestBRank{iInput,2};
end
for iOutput=1:nOutput
    vOptMu(iOutput,1)=vSoluBestBRank{iOutput+nInput,2};
end
for jDMU=1:J
    vEffMeasure(jDMU,1)=mOutput(jDMU,:)*vOptMu-mInput(jDMU,:)*vOptNu;
end
if round(Aeq*[vOptNu',vOptMu']',2)~=1
    [solution, outargstruc] = mpsg_solver(problem_statement_WorstRank_VAN, iargstruc_Rank);
    fval= tbpsg_solution(solution, outargstruc,'objective');  
    status=tbpsg_solution(solution, outargstruc,'solution_status');
    vTime=tbpsg_solution(solution, outargstruc,'time');
    RunTime=max(RunTime,vTime(3));
    WorstRank=J-J*fval; 
end



